%global shortname client

%global submodule_stub_server stub-server
%global submodule_rest zanata-rest-%{shortname}
%global submodule_commands zanata-%{shortname}-commands
%global submodule_cli zanata-cli
%global findbugs_ver_min 3.0.0
%global javac_source_ver 1.8
%global java_ver_min %{javac_source_ver}.0
%global jersey_ver_min 1.17
%global resteasy_ver_min 3.0.6
%global zanata_parent_ver 28
%global zanata_api_ver 3.9.1
%global zanata_common_ver 3.9.1
%if 0%{?fedora} >= 23
%global jersey_pkg_name jersey1
%else
%global jersey_pkg_name jersey
%endif
%global jersey_version %(rpm -q --qf "%%{version}" %{jersey_pkg_name})

Name:           zanata-%{shortname}
Version:        3.9.1
Release:        2%{?dist}
Summary:        Zanata client module

Group:          Development/Tools
License:        LGPLv2+
URL:            https://github.com/zanata/%{name}
Source0:        https://github.com/zanata/%{name}/archive/%{shortname}-%{version}.zip

BuildArch:      noarch

BuildRequires:  maven-local
BuildRequires:  java-devel >= 1:%{java_ver_min}
BuildRequires:  args4j >= 2.0.25
BuildRequires:  exec-maven-plugin
BuildRequires:  findbugs >= %{findbugs_ver_min}
BuildRequires:  %{jersey_pkg_name} >= %{jersey_ver_min}
BuildRequires:  %{jersey_pkg_name}-contribs >= %{jersey_ver_min}
BuildRequires:  jetty-servlet
BuildRequires:  jetty-servlets
BuildRequires:  jgettext
BuildRequires:  maven-dependency-plugin
BuildRequires:  mvn(com.sun:tools)
BuildRequires:  mvn(net.sourceforge.findbugs:annotations)
BuildRequires:  mvn(org.apache.commons:commons-exec)
BuildRequires:  mvn(org.apache.maven.plugins:maven-clean-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-deploy-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-install-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-site-plugin)
BuildRequires:  mvn(org.jboss:jboss-parent:pom:)
BuildRequires:  mvn(org.jboss.resteasy:jaxrs-api)
BuildRequires:  mvn(org.mockito:mockito-core)
BuildRequires:  opencsv
BuildRequires:  openprops
BuildRequires:  powermock-api-mockito
BuildRequires:  powermock-core
BuildRequires:  powermock-junit4
BuildRequires:  resteasy >= %{resteasy_ver_min}
BuildRequires:  xom
BuildRequires:  zanata-parent >= %{zanata_parent_ver}
BuildRequires:  zanata-api >= %{zanata_api_ver}-2
BuildRequires:  zanata-common >= %{zanata_common_ver}

Requires:       java-headless >= 1:%{java_ver_min}
Requires:       args4j >= 2.0.25
Requires:       %{jersey_pkg_name} >= %{jersey_ver_min}
Requires:       %{jersey_pkg_name}-contribs >= %{jersey_ver_min}
Requires:       jgettext
Requires:       mvn(org.apache.commons:commons-exec)
Requires:       opencsv
Requires:       openprops
Requires:       xom
Requires:       zanata-api >= %{zanata_api_ver}-2
Requires:       zanata-common >= %{zanata_common_ver}

%description
Zanata client modules.
Holds most of Zanata's client code, including Zanata CLI.
It also contains REST stub for interacting with a Zanata server.

%package javadoc
Summary:        Javadocs for %{name}
Group:          Documentation
Requires:       jpackage-utils
Requires:       %{name} = %{version}-%{release}

%description javadoc
This package contains the API documentation for %{shortname}.
This includes sub modules:
%{submodule_rest}, %{submodule_commands} and %{submodule_cli}.

%prep
%setup -q -n %{name}-%{shortname}-%{version}

## main
%pom_disable_module stub-server
%pom_disable_module zanata-maven-plugin
%pom_remove_plugin :findbugs-maven-plugin
%pom_remove_dep org.simpleframework:simple
%pom_xpath_set "pom:properties/pom:jersey.version" %{jersey_version}

# Ensure it compile with supported java version
%pom_xpath_inject "pom:plugins" "<plugin><groupId>org.apache.maven.plugins</groupId><artifactId>maven-compiler-plugin</artifactId><configuration><source>%{javac_source_ver}</source><target>%{javac_source_ver}</target><fork>true</fork><verbose>true</verbose></configuration></plugin>"

## stub-server
#%pom_remove_dep com.google.code.findbugs:annotations %{submodule_stub_server}
%pom_remove_plugin :duplicate-finder-maven-plugin %{submodule_stub_server}

## rest
%pom_remove_dep org.zanata:stub-server %{submodule_rest}
%pom_remove_plugin :duplicate-finder-maven-plugin %{submodule_rest}

## command
%pom_remove_dep org.simpleframework:simple %{submodule_commands}

## cli
%pom_remove_plugin :appassembler-maven-plugin %{submodule_cli}
%pom_remove_plugin :maven-assembly-plugin %{submodule_cli}
%pom_remove_dep org.simpleframework:simple %{submodule_cli}
%pom_remove_dep org.powermock:powermock-module-junit4 %{submodule_cli}
%pom_xpath_inject "pom:dependency[pom:artifactId[text()='zanata-client-commands']]/pom:exclusions" "<exclusion><groupId>com.sun</groupId><artifactId>tools</artifactId></exclusion>" %{submodule_cli}

# stub-server
#rm  %{submodule_stub_server}/src/main/java/org/zanata/rest/service/Mock*
#rm  %{submodule_stub_server}/src/main/java/org/zanata/rest/service/StubbingServerRule.java

# rest
rm -fr %{submodule_rest}/src/test


# simpleframework in fedora is too old
rm %{submodule_cli}/src/test/java/org/zanata/client/HTTPMockContainer.java
rm %{submodule_cli}/src/test/java/org/zanata/client/ClientToServerTest.java
rm %{submodule_commands}/src/test/java/org/zanata/client/commands/HTTPMockContainer.java
rm %{submodule_commands}/src/test/java/org/zanata/client/commands/init/InitCommandTest.java
rm %{submodule_commands}/src/test/java/org/zanata/client/commands/init/ProjectPromptTest.java
rm %{submodule_commands}/src/test/java/org/zanata/client/commands/UpdateCheckerTest.java

# Fedora does not have powermock-1.6.1 yet
rm %{submodule_cli}/src/test/java/org/zanata/client/ZanataClientTest.java
rm %{submodule_commands}/src/test/java/org/zanata/client/commands/*.java
rm %{submodule_commands}/src/test/java/org/zanata/client/commands/init/*.java
rm %{submodule_commands}/src/test/java/org/zanata/client/commands/push/*.java
rm %{submodule_commands}/src/test/java/org/zanata/client/commands/pull/*.java

%build
# -Dmaven.local.debug=true
%mvn_build  -X -G -- -Dmdep.analyze.skip=true -DfailIfNoTests=false -DskipTests=true dependency:build-classpath -DincludeScope=compile -Dmdep.outputFile=%{name}-classpath.txt

%install
%mvn_install

rest_cp=$(cat %{submodule_rest}/%{name}-classpath.txt)
commands_cp=$(cat %{submodule_commands}/%{name}-classpath.txt)
cli_cp=$(cat %{submodule_cli}/%{name}-classpath.txt)
all_cp=$rest_cp:$commands_cp:$cli_cp

%global CLASSPATH $all_cp

mkdir -p %{buildroot}%{_bindir}

install -d -m 755 %{buildroot}%{_bindir}

rm %{buildroot}%{_javadocdir}/%{name}/javadoc.sh

# create wrapper script
# adapted from jpackage_script().
# We build CLASSPATH at build time and the script won't be able to access it at runtime
############# copied from jpackage_script() ###########################
cat > %{buildroot}%{_bindir}/zanata-cli << ZANATA_CLI
#!/bin/sh
#
# {name} script
# JPackage Project <http://www.jpackage.org/>

# Source functions library
. %{_javadir}-utils/java-functions

# Source system prefs
if [ -f %{_sysconfdir}/java/%{name}.conf ] ; then
  . %{_sysconfdir}/java/%{name}.conf
fi

# Source user prefs
if [ -f \$HOME/.%{name}rc ] ; then
  . \$HOME/.%{name}rc
fi

EXIT_FATAL_MISSING_DEPENDENCY=4

declare -a JreVerArray
IFS="._" read -r -a JreVerMinArray <<< "%{java_ver_min}"

function check_java_home(){
    local javaHome=\$1
    local javaCmd

    if [ -x \$javaHome/bin/java ];then
        javaCmd=\$javaHome/bin/java
    elif [ -x \$javaHome/jre/bin/java ];then
        javaCmd=\$javaHome/jre/bin/java
    else
        ## No executable in javaHome
        return 1
    fi

    jreVer=\$(\$javaCmd -version |& sed -n -e '/version/ s/.*"\(.*\)"/\1/ p')
    IFS="._"  read -r -a JreVerArray <<< "\$jreVer"

    for (( i=0; i< \${#JreVerMinArray[@]}; i++)) ;do
        if [ \${JreVerArray[\$i]} -gt \${JreVerMinArray[\$i]} ];then
            ## Version is newer
            return 0
        elif [ \${JreVerArray[\$i]} -lt \${JreVerMinArray[\$i]} ];then
            ## Version is older
            return 1
        fi
    done
    ## version is equal
    return 0
}

JAVA_HOME_ORIG="\$JAVA_HOME"
JAVA_HOME=
for JavaHome in "\$JAVA_HOME_ORIG" /etc/alternatives/jre_%{java_ver_min}; do
    if check_java_home "\$JavaHome" ; then
    JAVA_HOME=\$JavaHome
    fi
done

if [ -z "\$JAVA_HOME" ];then
    echo "JRE %{java_ver_min} is not found. Please install it or specify JAVA_HOME" > /dev/stderr
    exit \$EXIT_FATAL_MISSING_DEPENDENCY
fi

# Configuration
MAIN_CLASS=org.zanata.client.ZanataClient
BASE_JARS="%{name} slf4j/log4j12 opencsv"
CLASSPATH=%{CLASSPATH}

# Set parameters
set_jvm
# we have built CLASSPATH above
set_classpath \$BASE_JARS

# Let's start
run "\$@"
ZANATA_CLI

chmod 755 %{buildroot}%{_bindir}/zanata-cli
#################################################################


%files -f .mfiles
%dir %{_javadir}/%{name}
%{_bindir}/zanata-cli
%doc README.txt

%files javadoc -f .mfiles-javadoc

%changelog
* Tue Jul 26 2016 Ding-Yi Chen <dchen@redhat.com> 3.9.1-2
- Require zanata-api-3.9.1-2, which has correct dependency.

* Mon Jul 18 2016 Ding-Yi Chen <dchen@redhat.com> 3.9.1-1
- Upstream update to version 3.9.1

* Wed May 25 2016 Ding-Yi Chen <dchen@redhat.com> 3.9.0-1
- Upstream update to version 3.9.0

* Thu Nov 26 2015 Ding-Yi Chen <dchen@redhat.com> 3.8.4-1
- Upstream update to 3.8.4

* Thu Nov 26 2015 Ding-Yi Chen <dchen@redhat.com> 3.8.1-2
- Fix the case that alternative does not point to 1.8.0 or later.

* Sun Nov 22 2015 Ding-Yi Chen <dchen@redhat.com> 3.8.1-1
- Upgrade to upstream version 3.8.1
- Now require Java 1.8

* Tue Jul 14 2015 Ding-Yi Chen <dchen@redhat.com> 3.7.3-1
- Upgrade to upstream version 3.7.3

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Mar 31 2015 Ding-Yi Chen <dchen@redhat.com> 3.6.0-1
- Upstream update to 3.6.0
- Detail documentation https://github.com/zanata/zanata-client/tree/master/docs

* Tue Mar 03 2015 Ding-Yi Chen <dchen@redhat.com> 3.4.2-1
- Upstream update to 3.4.2
- Include licence (LGPL 2.1) in dist archives

* Mon Feb 02 2015 Ding-Yi Chen <dchen@redhat.com> 3.4.1-1
- Upstream update to 3.4.1

* Mon Jul 28 2014 Patrick Huang <pahuang@redhat.com> 3.3.2-3
- Add version restriction and fix exec script classpath

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Jun 02 2014 Patrick Huang <pahuang@redhat.com> 3.3.2-1
- Latest upstream version

* Fri Mar 28 2014 Michael Simacek <msimacek@redhat.com> - 3.3.0-2
- Use Requires: java-headless rebuild (#1067528)

* Thu Jan 09 2014 Patrick Huang <pahuang@redhat.com> 3.3.0-1
- Latest upstream version

* Wed Aug 28 2013 Patrick Huang <pahuang@redhat.com> 3.1.1-1
- Upstream update for newer version of RESTEasy

* Wed Aug 28 2013 Patrick Huang <pahuang@redhat.com> 3.1.0-1
- Upstream update

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu May 16 2013 Patrick Huang <pahuang@redhat.com> 2.2.0-2
- Change license to LGPLv2+

* Fri Mar 1 2013 Patrick Huang <pahuang@redhat.com> 2.2.0-1
- Upstream version update

* Mon Feb 11 2013 Patrick Huang <pahuang@redhat.com> 2.0.1-1
- Initial RPM package
